@@ -2,7 +2,7 @@ import jwt
 
 from typing import Union
 
-from gongish import HTTPBadRequest
+from gongish import HTTPBadRequest, HTTPUnauthorized
 
 from cytra.auth.principal import JWTPrincipal, DefaultJWTPrincipal
 
@@ -22,6 +22,10 @@ class Authenticator:
             return self.__class__.__jwt_principal__(app=self.app).load(
                 self.app.request.environ[self.header_token_key]
             )
+
+        except jwt.ExpiredSignatureError:
+            raise HTTPUnauthorized("Access token expired")
+
         except jwt.InvalidTokenError:
             pass
 
