@@ -51,7 +51,7 @@ class TestingApp:
             metadata.drop_all(bind=self.db.get_bind())
             metadata.create_all(bind=self.db.get_bind())
 
-        self.testapp = WebtestApp(self.app, json_encoder=jsonlib)
+        self.testapp = WebtestApp(self.app)
         self.testapp.extra_environ["HTTP_ACCEPT"] = "application/json"
         self.testapp.extra_environ["REMOTE_ADDR"] = "127.0.0.1"
         self.testapp.extra_environ["HTTP_APP_CLIENT"] = "MapleWeb-1.2.3-beta"
